@@ -15,7 +15,10 @@ import cdk8s_plus_26._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@awlsring/cdk8s-valheim", "0.0.7", __name__[0:-6], "cdk8s-valheim@0.0.7.jsii.tgz"
+    "@awlsring/cdk8s-valheim",
+    "0.0.11",
+    __name__[0:-6],
+    "cdk8s-valheim@0.0.11.jsii.tgz",
 )
 
 __all__ = [
